==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/Q3ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q3ExpressionDescription } from "./Q3ExpressionDescription";
/**
 * @hidden
 */
var Q3ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q3ExpressionDescriptionMetadata, _super);
    function Q3ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q3ExpressionDescriptionMetadata.b = function (a) {
        if (Q3ExpressionDescriptionMetadata.a == null) {
            Q3ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q3ExpressionDescriptionMetadata.c(Q3ExpressionDescriptionMetadata.a);
        }
        if (a.j(Q3ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(Q3ExpressionDescriptionMetadata.a);
    };
    Q3ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q3ExpressionDescriptionMetadata.d = function (a) {
        Q3ExpressionDescriptionMetadata.b(a);
        a.aa("Q3Expression", function () { return new Q3ExpressionDescription(); });
        a.z("Q3Expression", Q3ExpressionDescriptionMetadata.a);
    };
    Q3ExpressionDescriptionMetadata.$t = markType(Q3ExpressionDescriptionMetadata, 'Q3ExpressionDescriptionMetadata');
    Q3ExpressionDescriptionMetadata.a = null;
    return Q3ExpressionDescriptionMetadata;
}(Base));
export { Q3ExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/Q3ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q3ExpressionDescription } from "./Q3ExpressionDescription";
/**
 * @hidden
 */
var Q3ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q3ExpressionDescriptionMetadata, _super);
    function Q3ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q3ExpressionDescriptionMetadata.b = function (a) {
        if (Q3ExpressionDescriptionMetadata.a == null) {
            Q3ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q3ExpressionDescriptionMetadata.c(Q3ExpressionDescriptionMetadata.a);
        }
        if (a.k(Q3ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(Q3ExpressionDescriptionMetadata.a);
    };
    Q3ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q3ExpressionDescriptionMetadata.d = function (a) {
        Q3ExpressionDescriptionMetadata.b(a);
        a.ac("Q3Expression", function () { return new Q3ExpressionDescription(); });
        a.ab("Q3Expression", Q3ExpressionDescriptionMetadata.a);
    };
    Q3ExpressionDescriptionMetadata.$t = markType(Q3ExpressionDescriptionMetadata, 'Q3ExpressionDescriptionMetadata');
    Q3ExpressionDescriptionMetadata.a = null;
    return Q3ExpressionDescriptionMetadata;
}(Base));
export { Q3ExpressionDescriptionMetadata };
